==> aws-java-sdk-1.7.1-sources.jar: com/amazonaws/services/cloudsearch/model/transform/OptionStatusStaxUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudsearch.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudsearch.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Option Status StAX Unmarshaller
 */
public class OptionStatusStaxUnmarshaller implements Unmarshaller<OptionStatus, StaxUnmarshallerContext> {

    public OptionStatus unmarshall(StaxUnmarshallerContext context) throws Exception {
        OptionStatus optionStatus = new OptionStatus();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return optionStatus;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("CreationDate", targetDepth)) {
                    optionStatus.setCreationDate(DateStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("UpdateDate", targetDepth)) {
                    optionStatus.setUpdateDate(DateStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("UpdateVersion", targetDepth)) {
                    optionStatus.setUpdateVersion(IntegerStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("State", targetDepth)) {
                    optionStatus.setState(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("PendingDeletion", targetDepth)) {
                    optionStatus.setPendingDeletion(BooleanStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return optionStatus;
                }
            }
        }
    }

    private static OptionStatusStaxUnmarshaller instance;
    public static OptionStatusStaxUnmarshaller getInstance() {
        if (instance == null) instance = new OptionStatusStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.8.9.1-sources.jar: com/amazonaws/services/cloudsearch/model/transform/OptionStatusStaxUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudsearch.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudsearch.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Option Status StAX Unmarshaller
 * @deprecated Use {@link com.amazonaws.services.cloudsearchv2.model.transform.OptionStatusStaxUnmarshaller} instead.
 */
 @Deprecated
public class OptionStatusStaxUnmarshaller implements Unmarshaller<OptionStatus, StaxUnmarshallerContext> {

    public OptionStatus unmarshall(StaxUnmarshallerContext context) throws Exception {
        OptionStatus optionStatus = new OptionStatus();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return optionStatus;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("CreationDate", targetDepth)) {
                    optionStatus.setCreationDate(DateStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("UpdateDate", targetDepth)) {
                    optionStatus.setUpdateDate(DateStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("UpdateVersion", targetDepth)) {
                    optionStatus.setUpdateVersion(IntegerStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("State", targetDepth)) {
                    optionStatus.setState(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("PendingDeletion", targetDepth)) {
                    optionStatus.setPendingDeletion(BooleanStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return optionStatus;
                }
            }
        }
    }

    private static OptionStatusStaxUnmarshaller instance;
    public static OptionStatusStaxUnmarshaller getInstance() {
        if (instance == null) instance = new OptionStatusStaxUnmarshaller();
        return instance;
    }
}
